Group of rules related to theme colors.



# THM-001: Theme Colors

**Applies to:**

- [Theme](/general/theme)

**Fix State:** Not Automatically Fixable

```

All colors used in the report should be defined in the theme.
This helps to maintain consistency and makes it easier to change colors later.

```

# THM-002: Theme Colors Protanopia

**Applies to:**

- [Theme](/general/theme)

**Fix State:** Not Automatically Fixable

```

All data colors should be clearly distinguishable for color vision deficiency.
This rule is specifically for Protanopia color vision deficiency.

```

# THM-002: Theme Colors Deuteranopia

**Applies to:**

- [Theme](/general/theme)

**Fix State:** Not Automatically Fixable

```

All data colors should be clearly distinguishable for color vision deficiency.
This rule is specifically for Deuteranopia color vision deficiency.

```

# THM-003: Theme Colors Tritanopia

**Applies to:**

- [Theme](/general/theme)

**Fix State:** Not Automatically Fixable

```

All data colors should be clearly distinguishable for color vision deficiency.
This rule is specifically for Tritanopia color vision deficiency.

```
